CellBoundary class

Cell boundary as an ordered list of vertices in degrees.

Constructors

CellBoundary(List<LatLng> vertices)
Creates a CellBoundary from an ordered list of vertices.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertices List<LatLng>
The boundary vertices in order. Typically 6 for hexagons, 5 for pentagons.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited