polygonToCells function
Returns all cells whose centers are within the polygon at resolution.
Implementation
List<H3Index> polygonToCells(GeoPolygon polygon, int resolution) =>
_unsupported();
Returns all cells whose centers are within the polygon at resolution.
List<H3Index> polygonToCells(GeoPolygon polygon, int resolution) =>
_unsupported();