CellBoundary class
Cell boundary as an ordered list of vertices in degrees.
Constructors
-
CellBoundary(List<
LatLng> vertices) -
Creates a CellBoundary from an ordered list of
vertices.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited